#!/bin/bash

#
# fuss-dump.sh, script to dump a FUSS8 server data
# usage: ./fuss-dump.sh 
# save dump in fuss-server-dump-$(date +%F).tgz in the current dir
#
# Copyright (C) 2020 Simone Piccardi <piccardi@truelite.it>
#                    Progetto Fuss <info@fuss.bz.it>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program or from the site that you downloaded it
# from; if not, write to the Free Software Foundation, Inc., 59 Temple
# Place, Suite 330, Boston, MA  02111-1307   USA
#

# variables
DATAFILE=fuss-conf-dump.tar
LOG=fuss-dump.log

DUMPDIR=/var/backups/fuss-server
# create backup dir
[ -d $DUMPDIR ] || mkdir -m 700 $DUMPDIR
cd $DUMPDIR

exec 2> $LOG

# Archive configuration/data files to be saved
tar -cf $DATAFILE /etc/fuss-server/client_keys
tar -uf $DATAFILE /etc/fuss-server/firewall-*
tar -uf $DATAFILE /etc/fuss-server/dhcp-reservations
tar -uf $DATAFILE /etc/fuss-server/content-filter-allowed-sites
tar -uf $DATAFILE /etc/fuss-server/fuss-server-defaults.yaml
tar -uf $DATAFILE /etc/fuss-server/Credentials/id_rsa*
tar -uf $DATAFILE /var/lib/octofuss/octofuss.db
tar -uf $DATAFILE /etc/cups/printers.conf
tar -uf $DATAFILE /etc/cups/ppd/*
tar -uf $DATAFILE /etc/krb5kdc/stash
tar -uf $DATAFILE /etc/bind/named.added.conf.local
tar -uf $DATAFILE /etc/dhcp/dhcpd-added.conf
tar -uf $DATAFILE /root/.ssh/authorized_keys
tar -uf $DATAFILE /srv/clonezilla/computerList.txt

# optional files
for i in /etc/samba/shares.conf \
	 /etc/fuss-backup/fuss-backup.conf \
	 /etc/clusters
do  
    if [ -e $i ]; then
	tar -uf $DATAFILE $i
    fi
done

##
## additional files from changed location
##

tar --transform 's,etc/squid3/,etc/squid/,' -uf $DATAFILE /etc/squid3/squid-added-repo.conf 
# are these two commented really used?
# tar --transform 's,etc/dansguardian/,etc/e2guardian/,' /etc/dansguardian/lists/bannedsitelist 
# tar --transform 's,etc/dansguardian/,etc/e2guardian/,' /etc/dansguardian/lists/bannedextensionlist

##
## Saving other data outside files
##

# Dumps of service data 
slapcat -l ldap-dump.ldif
kdb5_util dump > krb5.dump

# Quota settings for the homes
QUOTA=$(grep usrquota /etc/fstab | awk '{print $2}')
if [ x$QUOTA != x'' ]
then
    repquota -u $QUOTA > quota-users.txt
fi
QUOTA=$(grep grpquota /etc/fstab | awk '{print $2}')
if [ x$QUOTA != x'' ]
then
    repquota -n -g $QUOTA > quota-groups.txt
fi

# old fuss-server config is copied for reference
cp /etc/fuss-server/fuss-server.yaml fuss-server.yaml.old 

cd -
# put all data in a single file
tar -czf fuss-server-dump-$(date +%F).tgz -C /var/backups/ fuss-server
